#!/bin/bash

# This script installs NVIDIA CUDA Toolkit, NVIDIA drivers, and cuDNN.
# It is intended for Ubuntu 22.04.
# Run this script with sudo privileges: sudo ./nvidia.sh

# Exit immediately if a command exits with a non-zero status.
set -e

echo "Starting NVIDIA tools installation..."

# Part 1: Install CUDA Toolkit and NVIDIA Drivers

echo "Setting up CUDA repository pin..."
wget https://developer.download.nvidia.com/compute/cuda/repos/ubuntu2204/x86_64/cuda-ubuntu2204.pin
sudo mv cuda-ubuntu2204.pin /etc/apt/preferences.d/cuda-repository-pin-600

echo "Downloading and installing CUDA repository..."
wget https://developer.download.nvidia.com/compute/cuda/12.9.1/local_installers/cuda-repo-ubuntu2204-12-9-local_12.9.1-575.57.08-1_amd64.deb
sudo dpkg -i cuda-repo-ubuntu2204-12-9-local_12.9.1-575.57.08-1_amd64.deb

echo "Copying CUDA keyring..."
sudo cp /var/cuda-repo-ubuntu2204-12-9-local/cuda-*-keyring.gpg /usr/share/keyrings/

echo "Updating package list..."
sudo apt-get update

echo "Installing CUDA Toolkit 12.9..."
sudo apt-get -y install cuda-toolkit-12-9

echo "Installing NVIDIA open drivers..."
sudo apt-get install -y nvidia-open

# Part 2: Install cuDNN

echo "Downloading and installing cuDNN repository..."
wget https://developer.download.nvidia.com/compute/cudnn/9.10.2/local_installers/cudnn-local-repo-ubuntu2204-9.10.2_1.0-1_amd64.deb
sudo dpkg -i cudnn-local-repo-ubuntu2204-9.10.2_1.0-1_amd64.deb

echo "Copying cuDNN keyring..."
sudo cp /var/cudnn-local-repo-ubuntu2204-9.10.2/cudnn-*-keyring.gpg /usr/share/keyrings/

echo "Updating package list again..."
sudo apt-get update

echo "Installing cuDNN..."
sudo apt-get -y install cudnn
sudo apt-get -y install cudnn-cuda-12

echo "NVIDIA tools installation completed successfully!"
echo "It is recommended to reboot your system to ensure all changes take effect."